/** @file store.h
 *
 * @brief Common back end store definitions.
 *
 * New store implementations should include this header.
 */


#ifndef _LSUP_STORE_H
#define _LSUP_STORE_H


/*
 * Store feature flags.
 *
 * NOTE: LSUP_STORE_PERM need only be set by an implementation based on whether
 * its path is on a default temporary dir (e.g. LSUP_MDB_RAMDISK_PATH). If this
 * flag is not set, it means the data will be cleared before the next execution
 * of the program. However, its being set does not guarantee the persistence of
 * the medium (i.e. a "permanent" store may have been created ad hoc on a
 * tempfs).
 */
#define LSUP_STORE_PERM     1<<0    /// Store is on a permanent location.
#define LSUP_STORE_CTX      1<<1    /// Store supports contexts (quads).
#define LSUP_STORE_IDX      1<<2    /// Store is fully SPO(C)-indexed.
#define LSUP_STORE_TXN      1<<3    /// Supports manual transaction handling.
#define LSUP_STORE_NET      1<<4    /// Store is over a network protocol.

#endif  /* _LSUP_STORE_H */
